/*
 * Copyright 2019-2023 PixlOne
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#include <backend/hidpp20/features/SmartShift.h>

using namespace logid::backend::hidpp20;

SmartShift::SmartShift(Device* dev) : Feature(dev, ID) {
}

SmartShift::SmartshiftStatus SmartShift::getStatus() {
    std::vector<uint8_t> params(0);
    SmartshiftStatus status{};
    auto response = callFunction(GetStatus, params);
    status.active = response[0] - 1;
    status.autoDisengage = response[1];
    status.defaultAutoDisengage = response[2];
    return status;
}

void SmartShift::setStatus(SmartshiftStatus status) {
    std::vector<uint8_t> params(3);
    if (status.setActive)
        params[0] = status.active + 1;
    if (status.setAutoDisengage)
        params[1] = status.autoDisengage;
    if (status.setDefaultAutoDisengage)
        params[2] = status.defaultAutoDisengage;
    callFunction(SetStatus, params);
}